@@ -87,8 +87,8 @@ void AudioBuild::copyConvert(AudioStream &input, AudioStream &output)
 		else
 			npages = output.bufStereo(buffer, samples);
 
-		if(!npages)
-			break;
+		// if(!npages)
+		//	break;
 	}
 
 	delete[] buffer;
